@@ -3,7 +3,7 @@
 
 from tornado.gen import coroutine
 
-from holmes.models import Domain, Request
+from holmes.models import Domain
 from holmes.handlers import BaseHandler
 
 
@@ -73,8 +73,18 @@ class DomainDetailsHandler(BaseHandler):
             "is_active": domain.is_active,
             "errorPercentage": error_percentage,
             "averageResponseTime": response_time_avg,
+            "homepageId": "",
+            "homepageReviewId": "",
         }
 
+        homepage = domain.get_homepage(self.db)
+
+        if homepage:
+            if homepage.uuid:
+                domain_json["homepageId"] = str(homepage.uuid)
+            if homepage.last_review_uuid:
+                domain_json["homepageReviewId"] = str(homepage.last_review_uuid)
+
         self.write_json(domain_json)
 
 
@@ -121,12 +131,12 @@ class DomainReviewsHandler(BaseHandler):
         )
 
         if term:
-            review_count = len(reviews)
+            review_count = None
         else:
             review_count = yield self.cache.get_active_review_count(domain)
 
         result = {
-            'reviewCount': review_count,
+            'reviewsCount': review_count,
             'pages': [],
         }
 
