@@ -116,19 +116,14 @@ class PageViolationsPerDayHandler(BaseHandler):
 class NextJobHandler(BaseHandler):
     @gen.coroutine
     def get(self):
-        current_page = int(self.get_argument('current_page', 1))
-        page_size = int(self.get_argument('page_size', 10))
-
         get_next_job_list = Page.get_next_job_list(
             self.db,
             self.application.config.REVIEW_EXPIRATION_IN_SECONDS,
-            current_page=current_page,
-            page_size=page_size
+            current_page=int(self.get_argument('current_page', 1)),
+            page_size=int(self.get_argument('page_size', 10)),
+            domain_filter=self.get_argument('domain_filter', None)
         )
 
-        review_count = self.girl.get('next_jobs_count')
-
-        result = {'reviewCount': review_count}
         pages = []
         for item in get_next_job_list:
             pages.append({
@@ -136,6 +131,4 @@ class NextJobHandler(BaseHandler):
                 'url': item.url,
             })
 
-        result['pages'] = pages
-
-        self.write_json(result)
+        self.write_json({'pages': pages})
