@@ -2,7 +2,6 @@
 # -*- coding: utf-8 -*-
 
 import sys
-import inspect
 import datetime
 from uuid import uuid4
 from functools import partial
@@ -10,7 +9,6 @@ from collections import defaultdict
 
 from holmes.cli import BaseCLI
 from holmes.models.domain import Domain
-from holmes.models.page import Page
 from holmes.models.violation import Violation
 from holmes.models.request import Request
 from holmes.utils import get_domain_from_url
@@ -24,13 +22,6 @@ def configure_materials(girl, db, config):
         config.MATERIALS_GRACE_PERIOD_IN_SECONDS['domains_details']
     )
 
-    girl.add_material(
-        'next_jobs_count',
-        partial(Page.get_next_jobs_count, db, config),
-        config.MATERIALS_EXPIRATION_IN_SECONDS['next_jobs_count'],
-        config.MATERIALS_GRACE_PERIOD_IN_SECONDS['next_jobs_count']
-    )
-
     girl.add_material(
         'violation_count_by_category_for_domains',
         partial(Violation.get_group_by_category_id_for_all_domains, db),
