@@ -3,7 +3,7 @@
 
 import sqlalchemy as sa
 from sqlalchemy.orm import relationship
-from sqlalchemy import func
+from sqlalchemy import func, distinct
 
 from holmes.models import Base
 
@@ -33,6 +33,11 @@ class Domain(Base):
         from holmes.models import Page
         return dict(db.query(Page.domain_id, sa.func.count(Page.id)).group_by(Page.domain_id).all())
 
+    def get_homepage(self, db):
+        from holmes.models import Page
+
+        return db.query(Page).filter(Page.url == self.url).first()
+
     def get_page_count(self, db):
         from holmes.models import Page
         return db.query(func.count(Page.id)).filter(Page.domain_id == self.id).scalar()
@@ -114,10 +119,10 @@ class Domain(Base):
                 Page.last_review_uuid, Page.violations_count
             ) \
             .filter(Page.last_review_date != None) \
-            .filter(Page.domain == self) \
+            .filter(Page.domain == self)
 
         if url_starts_with:
-            items_query = items_query.filter(Page.url.like('%s%%' % url_starts_with))
+            items_query = items_query.filter(Page.url.like('%s/%s%%' % (self.url, url_starts_with)))
 
         items = items_query.order_by('violations_count desc')[lower_bound:upper_bound]
 
@@ -130,7 +135,7 @@ class Domain(Base):
     def get_active_review_count(self, db, url_starts_with=None):
         from holmes.models import Review, Page
 
-        query = db.query(func.count(Review.id))
+        query = db.query(func.count(distinct(Review.page_id)))  # See #111
 
         if url_starts_with:
             query = query.join(Page, Page.id == Review.page_id) \
