@@ -122,7 +122,8 @@ class Page(Base):
                     raise
 
     @classmethod
-    def get_next_job_list(cls, db, expiration, current_page=1, page_size=200):
+    def get_next_job_list(cls, db, expiration, current_page=1, page_size=200,
+                          domain_filter=None):
         from holmes.models import Domain
 
         lower_bound = (current_page - 1) * page_size
@@ -130,8 +131,15 @@ class Page(Base):
 
         expired_time = datetime.utcnow() - timedelta(seconds=expiration)
 
-        active_domains = Domain.get_active_domains(db)
-        active_domains_ids = [item.id for item in active_domains]
+        if domain_filter:
+            domain = Domain.get_domain_by_name(domain_filter, db)
+            if domain and domain.is_active:
+                active_domains_ids = [domain.id]
+            else:
+                return []
+        else:
+            active_domains = Domain.get_active_domains(db)
+            active_domains_ids = [item.id for item in active_domains]
 
         pages_query = db \
             .query(
@@ -149,27 +157,6 @@ class Page(Base):
 
         return pages_query[lower_bound:upper_bound]
 
-    @classmethod
-    def get_next_jobs_count(cls, db, config):
-        from holmes.models import Domain
-
-        expiration = config.REVIEW_EXPIRATION_IN_SECONDS
-        expired_time = datetime.utcnow() - timedelta(seconds=expiration)
-
-        active_domains = Domain.get_active_domains(db)
-        active_domains_ids = [item.id for item in active_domains]
-
-        return db \
-                .query(
-                    sa.func.count(Page.id)
-                ) \
-                .filter(Page.domain_id.in_(active_domains_ids)) \
-                .filter(or_(
-                    Page.last_review_date == None,
-                    Page.last_review_date <= expired_time
-                )) \
-                .scalar()
-
     @classmethod
     @return_future
     def add_page(cls, db, cache, url, score, fetch_method, publish_method, config, callback):
@@ -270,10 +257,6 @@ class Page(Base):
                 query_params
             )
 
-            cache.increment_page_count(domain)
-            cache.increment_page_count()
-            cache.increment_next_jobs_count()
-
         except Exception:
             err = sys.exc_info()[1]
             if 'Duplicate entry' in str(err):
